summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/dialogs/pkgcontentspage.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/dialogs/pkgcontentspage.h')
-rw-r--r--umbrello/umbrello/dialogs/pkgcontentspage.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/umbrello/umbrello/dialogs/pkgcontentspage.h b/umbrello/umbrello/dialogs/pkgcontentspage.h
index ef6faff1..65db8d8f 100644
--- a/umbrello/umbrello/dialogs/pkgcontentspage.h
+++ b/umbrello/umbrello/dialogs/pkgcontentspage.h
@@ -32,10 +32,10 @@ public:
/**
* Constructs an instance of PkgContentsPage.
*
* @param tqparent The tqparent of the page.
* @param pkg The UMLPackage being represented.
*/
- PkgContentsPage(TQWidget *tqparent, UMLPackage *pkg);
+ PkgContentsPage(TQWidget *parent, UMLPackage *pkg);
/**
* Standard destructor.
@@ -32,10 +32,10 @@ public:
* Constructs an instance of PkgContentsPage.
*
- * @param tqparent The tqparent of the page.
+ * @param parent The parent of the page.
* @param pkg The UMLPackage being represented.
*/